Construct a finite-difference gradient function
make_fd_grad.RdBuilds a function that computes the numerical gradient of a distribution's CDF with respect to a single parameter using central differences.

make_fd_grad.RdBuilds a function that computes the numerical gradient of a distribution's CDF with respect to a single parameter using central differences.